import { Component, Input, OnInit } from '@angular/core'
import { MqttclientService } from '../mqttclient.service'
import {coerceNumberProperty} from '@angular/cdk/coercion'

@Component({
  selector: 'heatingcontroller',
  template: `
  <div [ngStyle]="{ 'text-align': 'center', 'background-color':'lightgrey', 'border-radius':'10px', 
  'width': '300px', 'padding':'5px', 'margin': '5px 5px 5px 0',
  'font-family': 'sans-serif' }">
  {{label}}
  <p>
  <button mat-raised-button color="primary" (click)="clickOff()" [ngStyle]="{'font-size':'100%'}">off</button>
  <button mat-raised-button color="accent" (click)="clickOn()" [ngStyle]="{'font-size':'100%'}">on</button>
  <button mat-raised-button color="warn" (click)="clickForceOn()" [ngStyle]="{'font-size':'100%'}">forceOn</button>
  </p>
  <p>
  <mat-form-field [ngStyle]="{'margin':'10px', 'width':'40%'}">
    <input type="checkbox" [(ngModel)]="enableCurrentTemperature">
    <input matInput type="number" placeholder="Current" [(ngModel)]="currentTemperature"
           (click)="setCurrentTemperature()" (keyup)="setCurrentTemperature()"
           [disabled]="! enableCurrentTemperature">
  </mat-form-field>
  <mat-form-field [ngStyle]="{'margin':'10px', 'width':'40%'}">
    <input type="checkbox" [(ngModel)]="enablePresetTemperature">
    <input matInput type="number" placeholder="Preset" [(ngModel)]="presetTemperature" 
           (click)="setPresetTemperature()" (keyup)="setPresetTemperature()"
           [disabled]="! enablePresetTemperature">
  </mat-form-field>
  </p>
  </div>
  `
  
})
export class HeatingControllerComponent implements OnInit {
  @Input() topicPre : string = 'invalid'
  commandTopic : string = 'invalid'
  presetTopic : string = 'invalid'
  feedbackPresetTopic : string = 'invalid'
  temperatureTopic : string = 'invalid'
  feedbackTemperatureTopic : string = 'invalid'
  @Input() label : string = 'invalid'

  enableCurrentTemperature : boolean = false
  currentTemperature : number = 20
  enablePresetTemperature : boolean = false
  presetTemperature : number = 20
  
  constructor(private mqttclientService : MqttclientService) { }
  
  ngOnInit() {
    this.commandTopic = this.topicPre + '/command'
    this.presetTopic = this.topicPre + '/presetTemperature'
    this.feedbackPresetTopic = this.topicPre + '/presetTemperature/feedback'
    this.temperatureTopic = this.topicPre + '/temperature'
    this.feedbackTemperatureTopic = this.topicPre + '/temperature/feedback'

    this.mqttclientService.register(this.feedbackTemperatureTopic, (message: string) => {
      this.currentTemperature = parseInt(message)
    })
    this.mqttclientService.register(this.feedbackPresetTopic, (message: string) => {
      this.presetTemperature = parseInt(message)
    })
  }
  
  clickOn() {
    console.log(`click on for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "ON")
  }
  
  clickForceOn() {
    console.log(`click absent for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "FORCE_ON")
  }
  
  clickOff() {
    console.log(`click off for ${this.commandTopic}`)
    this.mqttclientService.publish(this.commandTopic, "OFF")
  }
  
  setCurrentTemperature() {
    console.log(`click on currentTemperature ${this.currentTemperature}`)
  }

  setPresetTemperature() {
    console.log(`click on presetTemperature ${this.presetTemperature}`)
  }
}

